Fix minor compiler issues.

Reviewed-by: Andy Polyakov <appro@openssl.org>
Reviewed-by: Rich Salz <rsalz@openssl.org>
(Merged from https://github.com/openssl/openssl/pull/3220)
diff --git a/ssl/statem/statem.c b/ssl/statem/statem.c
index 92a0e8f..e63d0ad 100644
--- a/ssl/statem/statem.c
+++ b/ssl/statem/statem.c
@@ -172,13 +172,13 @@
  * Called when we are in SSL_read*(), SSL_write*(), or SSL_accept()
  * /SSL_connect()/SSL_do_handshake(). Used to test whether we are in an early
  * data state and whether we should attempt to move the handshake on if so.
  * |send| is 1 if we are attempting to send data (SSL_write*()), 0 if we are
  * attempting to read data (SSL_read*()), or -1 if we are in SSL_do_handshake()
  * or similar.
  */
-void ossl_statem_check_finish_init(SSL *s, int send)
+void ossl_statem_check_finish_init(SSL *s, int sending)
 {
-    if (send == -1) {
+    if (sending == -1) {
         if (s->statem.hand_state == TLS_ST_PENDING_EARLY_DATA_END
                 || s->statem.hand_state == TLS_ST_EARLY_DATA) {
             ossl_statem_set_in_init(s, 1);
@@ -191,16 +191,16 @@
             }
         }
     } else if (!s->server) {
-        if ((send && (s->statem.hand_state == TLS_ST_PENDING_EARLY_DATA_END
+        if ((sending && (s->statem.hand_state == TLS_ST_PENDING_EARLY_DATA_END
                       || s->statem.hand_state == TLS_ST_EARLY_DATA)
                   && s->early_data_state != SSL_EARLY_DATA_WRITING)
-                || (!send && s->statem.hand_state == TLS_ST_EARLY_DATA)) {
+                || (!sending && s->statem.hand_state == TLS_ST_EARLY_DATA)) {
             ossl_statem_set_in_init(s, 1);
             /*
              * SSL_write() has been called directly. We don't allow any more
              * writing of early data.
              */
-            if (send && s->early_data_state == SSL_EARLY_DATA_WRITE_RETRY)
+            if (sending && s->early_data_state == SSL_EARLY_DATA_WRITE_RETRY)
                 s->early_data_state = SSL_EARLY_DATA_FINISHED_WRITING;
         }
     } else {
@@ -172,13 +172,13 @@
  * /SSL_connect()/SSL_do_handshake(). Used to test whether we are in an early
  * data state and whether we should attempt to move the handshake on if so.
- * |send| is 1 if we are attempting to send data (SSL_write*()), 0 if we are
+ * |sending| is 1 if we are attempting to send data (SSL_write*()), 0 if we are
  * attempting to read data (SSL_read*()), or -1 if we are in SSL_do_handshake()
  * or similar.